A MGF parser
=======================

This project allow you to read MGF files.
To read a MGF File use the function read_mgf(path).
This function will be return a dict with all informations.

If you have a problem to parse a MGF file please send it to me on the 
email : aurelien.vezin at etu.unistra.fr 
